<?php

class sysaftersales_api_refundapply_restore {

    /**
     * 接口作用说明
     */
    public $apiDescription = '平台对退款申请进行退款处理';

    public function getParams()
    {
        $return['params'] = array(
            'refunds_id' => ['type'=>'string','valid'=>'required', 'description'=>'退款申请单编号'],
            'refundsData' => ['type'=>'json','valid'=>'required', 'description'=>'退款单内容'],
        );
        return $return;
    }

    public function update($params)
    {
        $refundsData = json_decode($params['refundsData'],true);

        $filter['refunds_id'] = $params['refunds_id'];
        $objMdlRefunds = app::get('sysaftersales')->model('refunds');
        $refunds = $objMdlRefunds->getRow('status,aftersales_bn,refunds_type,user_id,shop_id,tid,oid',$filter);

        if( !in_array($refunds['status'],['3','5','6']) )
        {
            throw new \LogicException(app::get('sysaftersales')->_('当前申请还未审核'));
        }

        $refundsData['refunds_type'] = $refunds['refunds_type'];

        if( $refunds['refunds_type'] != '1' )//退款类型，售后退款
        {
            $refundsData['aftersales_bn'] = $refunds['aftersales_bn'];
        }

        try{
            unset($params['refundsData']);
            app::get('sysaftersales')->rpcCall('refund.create',$refundsData);
        }
        catch(\LogicException $e)
        {
            throw new \LogicException(app::get('sysaftersales')->_($e->getMessage()));
        }

        $db = app::get('sysaftersales')->database();
        $db->beginTransaction();

        try
        {
            //更新退款申请单
            $params['status'] ="1";
            $result = $objMdlRefunds->update($params,$filter);
            if(!$result)
            {
                throw new \LogicException(app::get('sysaftersales')->_('退款申请单更新失败'));
            }

            //如果为售后，则更新售后单状态
            if( $refunds['refunds_type'] != '1' )//退款类型，售后退款
            {
                $refundFee = $refundsData['money'];
                $this->__afsRefundSucc($refunds, $refundFee);
            }
            else//取消订单退款
            {
                //取消退款成功后，更新取消成功后操作
                app::get('sysaftersales')->rpcCall('trade.cancel.succ',['tid'=>$refunds['tid'],'shop_id'=>$refunds['shop_id']]);
            }
        }
        catch (\Exception $e)
        {
            $db->rollback();
            throw $e;
        }
        $db->commit();
        return true;
    }

    private function __afsRefundSucc($refunds, $refundFee)
    {
        $objMdlAftersales = app::get('sysaftersales')->model('aftersales');
        $aftersales = $objMdlAftersales->getRow('progress,status,tid,oid,user_id,shop_id',array('aftersales_bn'=>$refunds['aftersales_bn']));
        if($aftersales['tid'] != $refunds['tid'] || $aftersales['oid'] != $refunds['oid'] || $aftersales['user_id'] != $refunds['user_id'] || $aftersales['shop_id'] != $refunds['shop_id'])
        {
            throw new \LogicException(app::get('sysaftersales')->_('数据有误，请重新处理'));
        }

        if(in_array($aftersales['progress'],['3','4','6','7']) || in_array($aftersales['status'],['2','3']))
        {
            throw new \LogicException(app::get('sysaftersales')->_('当前处理异常，无法处理'));
        }

        $afterparams['progress'] = '7';
        $afterparams['status'] = '2';
        $afterFilter['aftersales_bn'] = $refunds['aftersales_bn'];
        $result = $objMdlAftersales->update($afterparams,$afterFilter);
        if(!$result)
        {
            throw new \LogicException(app::get('sysaftersales')->_('售后单状态更新失败'));
        }

        try
        {
            //更新字订单售后状态
            $orderparams['oid'] = $refunds['oid'];
            $orderparams['tid'] = $refunds['tid'];
            $orderparams['user_id'] = $refunds['user_id'];
            $orderparams['aftersales_status'] = 'SUCCESS';
            $orderparams['refund_fee'] = $refundFee;
            app::get('sysaftersales')->rpcCall('order.aftersales.status.update', $orderparams);
        }
        catch( Exception $e)
        {
            throw new \LogicException($e->getMessage());
        }
        return true;
    }
}
