<?php
/**
 *  处理退款
 */
class sysaftersales_refunds {

    public function __construct()
    {
        $this->objMdlRefunds = app::get('sysaftersales')->model('refunds');
        $this->objMath = kernel::single('ectools_math');
    }

    /**
     * 取消已付款的订单，创建退款申请单
     *
     * @param $tid  取消的订单ID
     * @param $status 取消的状态 用户申请取消订单 未审核，商家取消订单，平台取消订单
     * @param $refundsReason 取消订单原因
     * @param $shopId 店铺ID
     */
    public function cancelRefundApply($tid, $status, $refundsReason, $shopId)
    {
        $params = ['tid' => $tid,'fields' =>'tid,payed_fee,user_id,shop_id'];
        $tradeData = app::get('sysaftersales')->rpcCall('trade.get', $params);
        if( $tradeData && $shopId && $tradeData['shop_id'] != $shopId )
        {
            throw new \Exception("参数错误");
        }

        $insertData['user_id'] = $tradeData['user_id'];
        $insertData['shop_id'] = $shopId;
        $insertData['tid'] = $tid;
        $insertData['refunds_type'] = '1';
        $insertData['status'] = $status;
        $insertData['refunds_reason'] = $refundsReason;
        $insertData['total_price'] = $tradeData['payed_fee'];
        $insertData['created_time'] = time();
        $insertData['modified_time'] = time();

        return $this->objMdlRefunds->insert($insertData);
    }

    /**
     * 创建退款申请单，商家在需要进行退款处理的时候需要向平台发起退款申请，又平台进行退款处理
     *
     * @param array $data 申请退款数据
     * @param int   $tid  订单编号
     * @param int   $oid  子订单编号
     */
    public function afsRefundApply($data, $tid, $oid)
    {
        $params = ['tid' => $tid, 'oid' => $oid, 'fields' =>'tid,post_fee,orders.payment,user_id'];
        $tradeData = app::get('sysaftersales')->rpcCall('trade.get', $params);

        if( $data['total_price']  > $tradeData['orders'][0]['payment'] )
        {
            throw new \LogicException(app::get('sysaftersales')->_('商品退款金额不能大于付款金额'));
        }

        $insertData['aftersales_bn'] = $data['aftersales_bn'];
        $insertData['refunds_reason'] = $data['reason'];
        $insertData['total_price'] =  $data['total_price'];
        $insertData['status'] =  '3';//商家同意退款，则表示商家审核通过
        $insertData['tid'] =  $data['tid'];
        $insertData['oid'] =  $data['oid'];
        $insertData['shop_id'] =  $data['shop_id'];
        $insertData['user_id'] =  $tradeData['user_id'];
        $insertData['created_time'] = time();
        $insertData['modified_time'] = time();

        return $this->objMdlRefunds->insert($insertData);
    }

    public function updateStatus($aftersalesBn,$status)
    {
        return $this->objMdlRefunds->update(array('status'=>$status), array('aftersales_bn'=>$aftersalesBn));
    }
}

